@@ -4,7 +4,7 @@ package Test::Class::Moose;
 
 use 5.10.0;
 
-our $VERSION = '0.71';
+our $VERSION = '0.75';
 
 use Moose 2.0000;
 use Carp;
@@ -13,6 +13,11 @@ use Import::Into;
 use Sub::Attribute;
 use Test::Most ();
 
+# We don't use anything from these two modules, but we want to specify a
+# specific prereq version.
+use Test2 1.302015      ();
+use Test::More 1.302015 ();
+
 use Test::Class::Moose::AttributeRegistry;
 use Test::Class::Moose::Config;
 use Test::Class::Moose::Deprecated;
@@ -120,6 +125,13 @@ has 'test_class' => (
     default  => sub { ref $_[0] },
 );
 
+has 'test_instance_name' => (
+    is       => 'rw',
+    writer   => '_set_test_instance_name',
+    isa      => 'Str',
+    init_arg => undef,
+);
+
 has 'test_skip' => (
     is      => 'rw',
     isa     => 'Str',
@@ -132,8 +144,8 @@ has '_config_p' => (
 );
 
 sub import {
-    my $class = shift;
-    my %args  = @_;
+    shift;
+    my %args = @_;
 
     my $caller = caller;
 
@@ -196,7 +208,10 @@ sub runtests {
 sub _tcm_make_test_class_instances {
     my $test_class = shift;
 
-    return ( $test_class => $test_class->new(@_) );
+    my $instance = $test_class->new(@_);
+    $instance->_set_test_instance_name($test_class);
+
+    return $instance;
 }
 
 sub test_methods {
@@ -229,6 +244,8 @@ sub test_setup    { }
 sub test_teardown { }
 sub test_shutdown { }
 
+sub run_control_methods_on_skip {0}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -245,7 +262,7 @@ Test::Class::Moose - Serious testing for serious Perl
 
 =head1 VERSION
 
-version 0.71
+version 0.75
 
 =head1 SYNOPSIS
 
@@ -301,7 +318,7 @@ you get:
 Better docs will come later. You should already know how to use Moose and
 L<Test::Class>.
 
-=for Pod::Coverage Tags Tests runtests
+=for Pod::Coverage Tags Tests runtests run_control_methods_on_skip
 
 =head1 BASICS
 
@@ -529,6 +546,10 @@ you're about to run, you can do this:
 
 Runs at the end of each test method.
 
+By default, this is not run if the test class is skipped entirely. You can
+override the C<run_control_methods_on_skip> in your class to return a true
+value in order to force this method to be run when the class is skipped.
+
 =head2 C<test_shutdown>
 
  sub test_shutdown {
@@ -539,6 +560,10 @@ Runs at the end of each test method.
 
 Runs at the end of each test class.
 
+By default, this is not run if the test class is skipped entirely. You can
+override the C<run_control_methods_on_skip> in your class to return a true
+value in order to force this method to be run when the class is skipped.
+
 =head2 Overriding Test Control Methods
 
 To override a test control method, just remember that this is OO:
