@@ -4,12 +4,11 @@ package Test::Class::Moose::Config;
 
 use 5.10.0;
 
-our $VERSION = '0.71';
+our $VERSION = '0.75';
 
 use Moose;
 use Moose::Util::TypeConstraints;
 use TAP::Formatter::Color;
-use Test::Builder;
 use namespace::autoclean;
 
 subtype 'ArrayRefOfStrings', as 'Maybe[ArrayRef[Str]]';
@@ -34,14 +33,6 @@ has 'set_process_name' => (
     default => 0,
 );
 
-has 'builder' => (
-    is      => 'ro',
-    isa     => 'Test::Builder',
-    default => sub {
-        Test::Builder->new;
-    },
-);
-
 has 'statistics' => (
     is      => 'ro',
     isa     => 'Bool',
@@ -129,13 +120,12 @@ Test::Class::Moose::Config - Configuration information for Test::Class::Moose
 
 =head1 VERSION
 
-version 0.71
+version 0.75
 
 =head1 SYNOPSIS
 
  my $tc_config = Test::Class::Moose::Config->new({
      show_timing => 1,
-     builder     => Test::Builder->new,
      statistics  => 1,
      randomize   => 0,
  });
@@ -203,11 +193,6 @@ them. For example, if your network is down:
      exclude_tags => 'network',
  });
 
-=head2 C<builder>
-
-Usually defaults to C<< Test::Builder->new >>, but you could substitute your
-own if it conforms to the interface.
-
 =head2 C<randomize>
 
 Boolean. Will run test methods of a class in a random order.
