@@ -4,28 +4,14 @@ package Test::Class::Moose::Report;
 
 use 5.10.0;
 
-our $VERSION = '0.71';
+our $VERSION = '0.75';
 
 use Carp;
 use Moose;
 use namespace::autoclean;
 with 'Test::Class::Moose::Role::HasTimeReport';
 
-use List::Util qw( sum );
-
-has 'num_test_methods' => (
-    is      => 'rw',
-    isa     => 'Int',
-    writer  => 'set_num_test_methods',
-    default => 0,
-);
-
-has 'num_tests_run' => (
-    is      => 'rw',
-    isa     => 'Int',
-    writer  => 'set_tests_run',
-    default => 0,
-);
+use List::Util qw( first sum );
 
 has 'is_parallel' => (
     is      => 'ro',
@@ -50,26 +36,26 @@ sub num_test_instances {
     return sum map { $_->num_test_instances } $self->all_test_classes;
 }
 
+sub num_test_methods {
+    my $self = shift;
+    return scalar grep { !$_->is_skipped }
+      map              { $_->all_test_methods }
+      map              { $_->all_test_instances } $self->all_test_classes;
+}
+
+sub num_tests_run {
+    my $self = shift;
+    return sum map { $_->num_tests_run }
+      grep         { !$_->is_skipped }
+      map          { $_->all_test_methods }
+      map          { $_->all_test_instances } $self->all_test_classes;
+}
+
 sub all_test_classes {
     my $self = shift;
-    warn
-      "When running tests in parallel we are unable to store test classes\n"
-      if $self->is_parallel;
     return $self->_all_test_classes;
 }
 
-sub _inc_test_methods {
-    my ( $self, $test_methods ) = @_;
-    $test_methods //= 1;
-    $self->set_num_test_methods( $self->num_test_methods + $test_methods );
-}
-
-sub _inc_tests {
-    my ( $self, $tests ) = @_;
-    $tests //= 1;
-    $self->set_tests_run( $self->num_tests_run + $tests );
-}
-
 sub current_class {
     my $self = shift;
     return $self->test_classes->[-1];
@@ -158,7 +144,7 @@ Test::Class::Moose::Report - Test information for Test::Class::Moose
 
 =head1 VERSION
 
-version 0.71
+version 0.75
 
 =head1 SYNOPSIS
 
@@ -232,6 +218,46 @@ Reporting is currently in alpha. The interface is not guaranteed to be stable.
 
 =for Pod::Coverage plan
 
+=begin comment
+
+This is the code I used to generate the example in this module (plus a little
+manual editing to move the time key to the top of each nested hashref). This
+is based on the timing data from running basic.t.
+
+my $t = $report->timing_data;
+delete $t->{class}{'TestsFor::Basic::Subclass'};
+delete $t->{class}{'TestsFor::Basic'}{instance}{'TestsFor::Basic'}{method}{test_reporting};
+delete $t->{class}{'TestsFor::Basic'}{instance}{'TestsFor::Basic'}{method}{test_this_baby};
+use Devel::Dwarn; Dwarn _fudge($t);
+
+sub _fudge {
+    my $t = shift;
+
+    use Data::Visitor::Callback;
+
+    Data::Visitor::Callback->new(
+        hash => sub {
+            shift;
+            my $h = shift;
+
+            for my $k ( grep { exists $h->{$_} } qw( real system user ) ) {
+                if ($h->{$k} ) {
+                    $h->{$k} *= 10_000;
+                }
+                else {
+                    $h->{$k} = $h->{real} * ($k eq 'system' ? 0.15 : 0.85);
+                }
+            }
+
+            return $h;
+        },
+    )->visit($t);
+
+    return $t;
+}
+
+=end comment
+
 =head1 METHODS
 
 The top level report object for the whole test suite is returned from the
